pub struct Entry {Show 21 fields
pub associations: Vec<Association>,
pub auto_type_def_sequence: String,
pub auto_type_enabled: bool,
pub auto_type_obfuscation: Obfuscation,
pub background_color: Option<Color>,
pub binaries: HashMap<BinaryKey, BinaryValue>,
pub creation_time: DateTime<Utc>,
pub custom_icon_uuid: Option<CustomIconUuid>,
pub expires: bool,
pub expiry_time: DateTime<Utc>,
pub foreground_color: Option<Color>,
pub history: Vec<Entry>,
pub icon: Icon,
pub last_accessed: DateTime<Utc>,
pub last_modified: DateTime<Utc>,
pub location_changed: DateTime<Utc>,
pub override_url: String,
pub strings: StringsMap,
pub tags: String,
pub usage_count: i32,
pub uuid: EntryUuid,
}Expand description
An entry in the database.
Fields
associations: Vec<Association>Auto-type associations.
auto_type_def_sequence: StringDefault auto-type sequence.
auto_type_enabled: boolWhether auto-type is enabled.
auto_type_obfuscation: ObfuscationThe type of obfuscation to use for auto-typing.
background_color: Option<Color>The background color.
binaries: HashMap<BinaryKey, BinaryValue>Map with binaries.
creation_time: DateTime<Utc>The date and time this entry was created.
custom_icon_uuid: Option<CustomIconUuid>The identifier of this entry’s custom icon if any.
expires: boolWhether this entry expires.
expiry_time: DateTime<Utc>The date and time this entry will expire if expires is true.
foreground_color: Option<Color>The foreground color.
history: Vec<Entry>This entry’s history.
icon: IconThis entry’s icon.
last_accessed: DateTime<Utc>The date and time this entry was last accessed.
last_modified: DateTime<Utc>The date and time this entry was last modified.
location_changed: DateTime<Utc>The date and time the location of this entry was changed.
override_url: StringOverride URL.
strings: StringsMapMap with strings.
The tags associated with this entry.
usage_count: i32The usage count of this entry.
uuid: EntryUuidThe identifier of this entry.
Implementations
Sourceimpl Entry
impl Entry